@@ -1,9 +1,9 @@
 #' Fast creation of dummy variables
 #'
 #' dummy_cols() quickly creates dummy (binary) columns from character and
-#' factor type columns in the inputted data. This function is useful for
-#' statistical analysis when you want binary columns rather than
-#' character columns.
+#' factor type columns in the inputted data (and numeric columns if specified.)
+#' This function is useful for statistical analysis when you want binary
+#' columns rather than character columns.
 #'
 #' @family dummy functions
 #' @seealso \code{\link{dummy_rows}} For creating dummy rows
@@ -22,6 +22,16 @@
 #' (by alphabetical order) category that is tied for most frequent.
 #' @param sort_columns
 #' Sorts columns following factor order.
+#' @param ignore_na
+#' If TRUE, ignores any NA values in the column. If FALSE (default), then it
+#' will make a dummy column for value_NA and give a 1 in any row which has a
+#' NA value.
+#' @param split
+#' A string to split a column when multiple categories are in the cell. For
+#' example, if a variable is Pets and the rows are "cat", "dog", and "turtle",
+#' each of these pets would become its own dummy column. If one row is "cat, dog",
+#' then a split value of "," this row would have a value of 1 for both the cat
+#' and dog dummy columns.
 #'
 #' @return
 #' A data.frame (or tibble or data.table, depending on input data type) with
@@ -42,7 +52,9 @@ dummy_cols <- function(.data,
                        select_columns = NULL,
                        remove_first_dummy = FALSE,
                        remove_most_frequent_dummy = FALSE,
-                       sort_columns = FALSE) {
+                       sort_columns = FALSE,
+                       ignore_na = FALSE,
+                       split = NULL) {
 
   stopifnot(is.null(select_columns) || is.character(select_columns),
             select_columns != "",
@@ -89,6 +101,9 @@ dummy_cols <- function(.data,
 
   for (col_name in char_cols) {
     unique_vals <- as.character(unique(.data[[col_name]]))
+    if (ignore_na) {
+      unique_vals <- unique_vals[!is.na(unique_vals)]
+    }
 
     if (remove_most_frequent_dummy) {
       vals <- as.character(.data[[col_name]])
@@ -121,6 +136,20 @@ dummy_cols <- function(.data,
                           unique_value) == 1L),
                       j = paste0(col_name, "_", unique_value), value = 1L)
 
+      if (!is.null(split)) {
+        max_split_length <- max(sapply(strsplit(.data[[col_name]], split), length))
+        for (split_length in 1:max_split_length) {
+          data.table::set(.data, i =
+                            which(data.table::chmatch(
+                              as.character(trimws(sapply(strsplit(.data[[col_name]], split),
+                                                  `[`, split_length))),
+                              unique_value) == 1L),
+                          j = paste0(col_name, "_", unique_value), value = 1L)
+        }
+
+
+      }
+
     }
   }
 
